@@ -62,7 +62,8 @@ void usage(int verbose)
 int SetRootWindow(char *tline)
 {
 	Pixmap shapeMask = None, temp_pix = None, alpha = None;
-	int w, h, depth;
+	int w, h;
+	int depth;
 	int nalloc_pixels = 0;
 	Pixel *alloc_pixels = NULL;
 	char *file_path;
