@@ -414,7 +414,7 @@ static void __remove_window_decors(F_CMD_ARGS, FvwmDecor *d)
 		{
 			/* remove the extra title height now because we delete
 			 * the current decor before calling ChangeDecor(). */
-			t->frame_g.height -= t->decor->title_height;
+			t->g.frame.height -= t->decor->title_height;
 			t->decor = NULL;
 			ecc.w.fw = t;
 			ecc.w.wcontext = C_WINDOW;
@@ -1614,11 +1614,16 @@ Bool ReadDecorFace(char *s, DecorFace *df, int button, int verbose)
 
 			vc->num = num_coords;
 			vc->use_fgbg = 0;
-			vc->x = safemalloc(sizeof(char) * num_coords);
-			vc->y = safemalloc(sizeof(char) * num_coords);
-			vc->xoff = safemalloc(sizeof(char) * num_coords);
-			vc->yoff = safemalloc(sizeof(char) * num_coords);
-			vc->c = safemalloc(sizeof(char) * num_coords);
+			vc->x = (signed char*)safemalloc(sizeof(char) *
+							 num_coords);
+			vc->y = (signed char*)safemalloc(sizeof(char) *
+							 num_coords);
+			vc->xoff = (signed char*)safemalloc(sizeof(char) *
+							    num_coords);
+			vc->yoff = (signed char*)safemalloc(sizeof(char) *
+							    num_coords);
+			vc->c = (signed char*)safemalloc(sizeof(char) *
+							 num_coords);
 
 			/* get the points */
 			for (i = 0; i < vc->num; ++i)
@@ -2310,8 +2315,12 @@ void CMD_Destroy(F_CMD_ARGS)
 		XBell(dpy, 0);
 		return;
 	}
-	if (XGetGeometry(dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
-			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) != 0)
+	if (
+		XGetGeometry(
+			dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
+			(unsigned int*)&JunkWidth, (unsigned int*)&JunkHeight,
+			(unsigned int*)&JunkBW, (unsigned int*)&JunkDepth)
+		!= 0)
 	{
 		XKillClient(dpy, FW_W(fw));
 	}
@@ -2341,9 +2350,12 @@ void CMD_Close(F_CMD_ARGS)
 			dpy, FW_W(fw), _XA_WM_DELETE_WINDOW, CurrentTime);
 		return;
 	}
-	if (XGetGeometry(
-			 dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
-			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) != 0)
+	if (
+		XGetGeometry(
+			dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
+			(unsigned int*)&JunkWidth, (unsigned int*)&JunkHeight,
+			(unsigned int*)&JunkBW, (unsigned int*)&JunkDepth)
+		!= 0)
 	{
 		XKillClient(dpy, FW_W(fw));
 	}
@@ -2624,7 +2636,7 @@ void CMD_QuitScreen(F_CMD_ARGS)
 
 void CMD_Echo(F_CMD_ARGS)
 {
-	unsigned int len;
+	int len;
 
 	if (!action)
 	{
@@ -4393,7 +4405,7 @@ void CMD_State(F_CMD_ARGS)
 	int n;
 	FvwmWindow * const fw = exc->w.fw;
 
-	n = GetIntegerArguments(action, &action, &state, 1);
+	n = GetIntegerArguments(action, &action, (int *)&state, 1);
 	if (n <= 0)
 	{
 		return;
