@@ -558,6 +558,23 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 			SET_STICKY_ACROSS_DESKS(mask, on);
 			SETM_STICKY_ACROSS_DESKS(mask, 1);
 		}
+		else if (StrEquals(cond,"StickyIcon"))
+		{
+			SET_ICON_STICKY_ACROSS_PAGES(mask, on);
+			SET_ICON_STICKY_ACROSS_DESKS(mask, on);
+			SETM_ICON_STICKY_ACROSS_PAGES(mask, 1);
+			SETM_ICON_STICKY_ACROSS_DESKS(mask, 1);
+		}
+		else if (StrEquals(cond,"StickyAcrossPagesIcon"))
+		{
+			SET_ICON_STICKY_ACROSS_PAGES(mask, on);
+			SETM_ICON_STICKY_ACROSS_PAGES(mask, 1);
+		}
+		else if (StrEquals(cond,"StickyAcrossDesksIcon"))
+		{
+			SET_ICON_STICKY_ACROSS_DESKS(mask, on);
+			SETM_ICON_STICKY_ACROSS_DESKS(mask, 1);
+		}
 		else if (StrEquals(cond,"Maximized"))
 		{
 			SET_MAXIMIZED(mask, on);
@@ -862,12 +879,12 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 		if (FScreenIsEnabled() && !mask->my_flags.do_not_check_screen)
 		{
 			is_on_page = !!FScreenIsRectangleOnScreen(
-				NULL, FSCREEN_CURRENT, &(fw->frame_g));
+				NULL, FSCREEN_CURRENT, &(fw->g.frame));
 		}
 		else
 		{
 			is_on_page = !!IsRectangleOnThisPage(
-				&(fw->frame_g), Scr.CurrentDesk);
+				&(fw->g.frame), Scr.CurrentDesk);
 		}
 	}
 	is_on_global_page = 1;
@@ -875,7 +892,7 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	    mask->my_flags.do_check_desk_and_global_page)
 	{
 		is_on_global_page = !!IsRectangleOnThisPage(
-			&(fw->frame_g), Scr.CurrentDesk);
+			&(fw->g.frame), Scr.CurrentDesk);
 	}
 
 	if (mask->my_flags.do_check_desk_and_page)
@@ -1709,8 +1726,10 @@ void CMD_WindowId(F_CMD_ARGS)
 		}
 		else if (XGetGeometry(
 				 dpy, win, &JunkRoot, &JunkX, &JunkY,
-				 &JunkWidth, &JunkHeight, &JunkBW,
-				 &JunkDepth) != 0)
+				 (unsigned int*)&JunkWidth,
+				 (unsigned int*)&JunkHeight,
+				 (unsigned int*)&JunkBW,
+				 (unsigned int*)&JunkDepth) != 0)
 		{
 			if (cond_rc != NULL)
 			{
