@@ -336,7 +336,7 @@ ewmh_atom *ewmh_GetEwmhAtomByAtom(Atom atom, ewmh_atom_list_name list_name)
 
 void ewmh_ChangeProperty(
 	Window w, const char *atom_name, ewmh_atom_list_name list,
-	unsigned char *data, unsigned int length)
+	unsigned char *data, int length)
 {
 	ewmh_atom *a;
 	int format = 32;
@@ -381,7 +381,7 @@ static int atom_size(int format)
 }
 
 static
-void *atom_get(Window win, Atom to_get, Atom type, unsigned int *size)
+void *atom_get(Window win, Atom to_get, Atom type, int *size)
 {
 	unsigned char *retval;
 	Atom  type_ret;
@@ -434,7 +434,7 @@ void *atom_get(Window win, Atom to_get, Atom type, unsigned int *size)
 
 void *ewmh_AtomGetByName(
 	Window win, const char *atom_name, ewmh_atom_list_name list,
-	unsigned int *size)
+	int *size)
 {
 	ewmh_atom *a;
 	void *data = NULL;
@@ -725,7 +725,7 @@ void set_kde_sys_tray(void)
 
 void ewmh_AddToKdeSysTray(FvwmWindow *fw)
 {
-	unsigned int size = 0;
+	int size = 0;
 	Atom *val;
 	KstItem *t;
 
@@ -1506,7 +1506,7 @@ void ewmh_HandleWindowType(FvwmWindow *fw, window_style *style)
 {
 	Atom *val;
 	ewmh_atom *list = ewmh_atom_window_type;
-	unsigned int size = 0;
+	int size = 0;
 	int i = 0;
 	Bool found = False;
 
@@ -1598,7 +1598,7 @@ void EWMH_GetStyle(FvwmWindow *fw, window_style *style)
 
 static void ewmh_check_wm_pid(FvwmWindow *fw)
 {
-	unsigned int size = 0;
+	int size = 0;
 	Atom *val;
 
 	fw->ewmh_window_type = 0;
@@ -1909,10 +1909,8 @@ void EWMH_fullscreen(FvwmWindow *fw)
 	}
 	SET_EWMH_FULLSCREEN(fw,True);
 	apply_decor_change(fw);
-	fscr.xypos.x =
-		fw->frame_g.x + fw->frame_g.width / 2;
-	fscr.xypos.y =
-		fw->frame_g.y + fw->frame_g.height / 2;
+	fscr.xypos.x = fw->g.frame.x + fw->g.frame.width / 2;
+	fscr.xypos.y = fw->g.frame.y + fw->g.frame.height / 2;
 	FScreenGetScrRect(
 		&fscr, FSCREEN_XYPOS, &scr_g.x, &scr_g.y,
 		&scr_g.width, &scr_g.height);
