@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 #include <signal.h>
+#include <errno.h>
 #include <sys/stat.h>
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
@@ -57,7 +58,7 @@
 #include "misc.h"
 #include "screen.h"
 #include "builtins.h"
-#include "module_interface.h"
+#include "module_list.h"
 #include "colorset.h"
 #include "events.h"
 #include "eventhandler.h"
@@ -76,6 +77,7 @@
 #include "move_resize.h"
 #include "frame.h"
 #include "menus.h"
+#include "menubindings.h"
 #include "libs/FGettext.h"
 
 /* ---------------------------- local definitions -------------------------- */
@@ -150,7 +152,8 @@ XContext MenuContext;           /* context for fvwm menus */
 
 int JunkX = 0, JunkY = 0;
 Window JunkRoot, JunkChild;             /* junk window */
-unsigned int JunkWidth, JunkHeight, JunkBW, JunkDepth, JunkMask;
+int JunkWidth, JunkHeight, JunkBW, JunkDepth;
+unsigned int JunkMask;
 
 Bool debugging = False;
 Bool debugging_stack_ring = False;
@@ -164,7 +167,7 @@ char *state_filename = NULL;
 char *restart_state_filename = NULL;  /* $HOME/.fs-restart */
 
 Bool Restarting = False;
-int fd_width, x_fd;
+int x_fd;
 char *display_name = NULL;
 char *fvwm_userdir;
 char const *Fvwm_VersionInfo;
@@ -706,7 +709,7 @@ void Done(int restart, char *command)
 	 * SubstructureRedirect selected on the root window ==> windows end up
 	 * in nirvana. This explicitly happened with windows unswallowed by
 	 * FvwmButtons. */
-	ClosePipes();
+	module_kill_all();
 
 	exit(0);
 }
@@ -835,11 +838,11 @@ static void LoadDefaultLeftButton(DecorFace *df, int i)
 	case 0:
 	case 4:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 22;
 		v->y[0] = 39;
 		v->c[0] = 1;
@@ -856,11 +859,11 @@ static void LoadDefaultLeftButton(DecorFace *df, int i)
 		break;
 	case 1:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 32;
 		v->y[0] = 45;
 		v->x[1] = 68;
@@ -876,11 +879,11 @@ static void LoadDefaultLeftButton(DecorFace *df, int i)
 		break;
 	case 2:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 49;
 		v->y[0] = 49;
 		v->c[0] = 1;
@@ -897,11 +900,11 @@ static void LoadDefaultLeftButton(DecorFace *df, int i)
 		break;
 	case 3:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 32;
 		v->y[0] = 45;
 		v->c[0] = 1;
@@ -945,11 +948,11 @@ static void LoadDefaultRightButton(DecorFace *df, int i)
 	case 0:
 	case 3:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 25;
 		v->y[0] = 25;
 		v->c[0] = 1;
@@ -966,11 +969,11 @@ static void LoadDefaultRightButton(DecorFace *df, int i)
 		break;
 	case 1:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 39;
 		v->y[0] = 39;
 		v->c[0] = 1;
@@ -987,11 +990,11 @@ static void LoadDefaultRightButton(DecorFace *df, int i)
 		break;
 	case 2:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 49;
 		v->y[0] = 49;
 		v->c[0] = 1;
@@ -1008,11 +1011,11 @@ static void LoadDefaultRightButton(DecorFace *df, int i)
 		break;
 	case 4:
 		v->num = 5;
-		v->x = safemalloc(sizeof(char) * v->num);
-		v->y = safemalloc(sizeof(char) * v->num);
-		v->xoff = safemalloc(sizeof(char) * v->num);
-		v->yoff = safemalloc(sizeof(char) * v->num);
-		v->c = safecalloc(v->num, sizeof(char));
+		v->x = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->y = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->xoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->yoff = (signed char*)safemalloc(sizeof(char) * v->num);
+		v->c = (signed char*)safecalloc(v->num, sizeof(char));
 		v->x[0] = 36;
 		v->y[0] = 36;
 		v->c[0] = 1;
@@ -1348,6 +1351,7 @@ static void setVersionInfo(void)
 /* Sets some initial style values & such */
 static void SetRCDefaults(void)
 {
+#define RC_DEFAULTS_COMPLETE ((char *)-1)
 	int i;
 	/* set up default colors, fonts, etc */
 	const char *defaults[][3] = {
@@ -1390,6 +1394,16 @@ static void SetRCDefaults(void)
 			"\" Quit"
 		},
 		{ "Mouse 1 R A Menu MenuFvwmRoot", "", "" },
+		/* default menu navigation */
+		{ "Key Escape M A MenuClose", "", "" },
+		{ "Key Return M A MenuSelectItem", "", "" },
+		{ "Key Left M A MenuCursorLeft", "", "" },
+		{ "Key Right M A MenuCursorRight", "", "" },
+		{ "Key Up M A MenuMoveCursor -1", "", "" },
+		{ "Key Down M A MenuMoveCursor 1", "", "" },
+		{ "Mouse 1 M A MenuSelectItem", "", "" },
+		/* don't add anything below */
+		{ RC_DEFAULTS_COMPLETE, "", "" },
 		{ "Read "FVWM_DATADIR"/ConfigFvwmDefaults", "", "" },
 		{ NULL, NULL, NULL }
 	};
@@ -1400,6 +1414,11 @@ static void SetRCDefaults(void)
 		exec_context_changes_t ecc;
 		char *cmd;
 
+		if (defaults[i][0] == RC_DEFAULTS_COMPLETE)
+		{
+			menu_bindings_startup_complete();
+			continue;
+		}
 		ecc.type = Restarting ? EXCT_RESTART : EXCT_INIT;
 		ecc.w.wcontext = C_ROOT;
 		exc = exc_create_context(&ecc, ECC_TYPE | ECC_WCONTEXT);
@@ -1408,6 +1427,7 @@ static void SetRCDefaults(void)
 		execute_function(NULL, exc, cmd, 0);
 		exc_destroy_context(exc);
 	}
+#undef RC_DEFAULTS_COMPLETE
 
 	return;
 }
@@ -1427,7 +1447,7 @@ static int CatchFatal(Display *dpy)
 	/* No action is taken because usually this action is caused by someone
 	   using "xlogout" to be able to switch between multiple window managers
 	*/
-	ClosePipes();
+	module_kill_all();
 	exit(1);
 
 	/* to make insure happy */
@@ -1675,6 +1695,34 @@ const char *getInitFunctionName(int n)
 	return initFunctionNames[n >= 0 && n < 3? n: 3];
 }
 
+#ifndef _PATH_DEVNULL
+#	define _PATH_DEVNULL "/dev/null"
+#endif
+static void reopen_fd(int fd, char* mode, FILE *of)
+{
+	struct stat sbuf;
+	FILE *f;
+	int rc;
+
+	errno = 0;
+	rc = fstat(fd, &sbuf);
+	if (rc == 0)
+	{
+		return;
+	}
+	else if (errno != EBADF)
+	{
+		exit(77);
+	}
+	f = freopen(_PATH_DEVNULL, mode, of);
+	if (f == 0 || fileno(f) != fd)
+	{
+		exit(88);
+	}
+
+	return;
+}
+
 /***********************************************************************
  *
  *  Procedure:
@@ -1700,6 +1748,17 @@ int main(int argc, char **argv)
 
 	DBUG("main", "Entered, about to parse args");
 
+	fvwmlib_init_max_fd();
+	/* close open fds */
+	for (i = 3; i < fvwmlib_max_fd; i++)
+	{
+		close(i);
+	}
+	/* reopen stdin, stdout and stderr if necessary */
+	reopen_fd(0, "rb", stdin);
+	reopen_fd(1, "wb", stdout);
+	reopen_fd(2, "wb", stderr);
+
 	memset(&Scr, 0, sizeof(Scr));
 	/* for use on restart */
 	g_argv = (char **)safemalloc((argc + 4) * sizeof(char *));
@@ -2042,7 +2101,8 @@ int main(int argc, char **argv)
 		if (dn == NULL)
 		{
 			fvwm_msg(
-				ERR, "main", "couldn't find default display (%s)",
+				ERR,
+				"main", "couldn't find default display (%s)",
 				XDisplayName(dn));
 		}
 		else
@@ -2117,7 +2177,6 @@ int main(int argc, char **argv)
 	}
 	FScreenInit(dpy);
 	x_fd = XConnectionNumber(dpy);
-	fd_width = GetFdWidth();
 
 #ifdef HAVE_X11_FD
 	if (fcntl(x_fd, F_SETFD, 1) == -1)
@@ -2422,7 +2481,6 @@ int main(int argc, char **argv)
 		Scr.FvwmRoot.cmap_windows = &Scr.NoFocusWin;
 	}
 	InitEventHandlerJumpTable();
-	initModules();
 
 	Scr.gray_bitmap =
 		XCreateBitmapFromData(dpy,Scr.Root,g_bits, g_width,g_height);
@@ -2514,7 +2572,7 @@ int main(int argc, char **argv)
 	valuemask = CWBackPixel | CWColormap | CWBorderPixel;
 
 	Scr.SizeWindow = XCreateWindow(
-		dpy, Scr.Root, 0, 0, 1, 1, (unsigned int)0, Pdepth,
+		dpy, Scr.Root, 0, 0, 1, 1, 0, Pdepth,
 		InputOutput, Pvisual, valuemask, &attributes);
 	resize_geometry_window();
 	initPanFrames();
