@@ -29,8 +29,8 @@
 #include "execcontext.h"
 #include "misc.h"
 #include "screen.h"
-#include "menustyle.h"
 #include "menudim.h"
+#include "menustyle.h"
 #include "menuitem.h"
 #include "decorations.h"
 
@@ -51,8 +51,7 @@
 /* ---------------------------- exported variables (globals) --------------- */
 
 /* ---------------------------- local functions ---------------------------- */
-void static
-clear_menu_item_background(
+static void clear_menu_item_background(
 	MenuPaintItemParameters *mpip, int x, int y, int w, int h)
 {
 	MenuStyle *ms = mpip->ms;
@@ -121,10 +120,66 @@ static void draw_tear_off_bar(
 	return;
 }
 
+static void draw_higlight_background(
+	struct MenuPaintItemParameters *mpip, int x, int y, int width,
+	int height, colorset_t *cs, GC gc)
+{
+	if (cs != NULL && cs->pixmap && cs->pixmap_type != PIXMAP_TILED)
+	{
+		Pixmap p;
+
+		p = CreateOffsetBackgroundPixmap(
+			dpy, mpip->w, x, y, width, height, cs, Pdepth, gc,
+			False);
+		switch (cs->pixmap_type)
+		{
+		case PIXMAP_STRETCH_X:
+			/* todo: optimize to only create one pixmap and gc per
+			 * mr. */
+		case PIXMAP_STRETCH_Y:
+		{
+			XGCValues gcv;
+			int gcm;
+			GC bgc;
+
+			gcv.tile = p;
+			gcv.fill_style = FillTiled;
+			gcm = GCFillStyle | GCTile;
+
+			/* vertcal gradients has to be aligned properly */
+			if (cs->pixmap_type == PIXMAP_STRETCH_Y)
+			{
+				gcv.ts_y_origin = y;
+				gcm|=GCTileStipYOrigin;
+			}
+			else if (cs->pixmap_type == PIXMAP_STRETCH_X)
+			{
+				gcv.ts_x_origin = x;
+				gcm|=GCTileStipXOrigin;
+			}
+
+			bgc = fvwmlib_XCreateGC(dpy, mpip->w, gcm, &gcv);
+			XFillRectangle(dpy, mpip->w, bgc, x, y, width, height);
+			XFreeGC(dpy, bgc);
+			break;
+		}
+		default:
+			XCopyArea(dpy, p, mpip->w, gc, 0, 0, width, height,
+				  x, y);
+			break;
+		}
+		XFreePixmap(dpy, p);
+	}
+	else
+	{
+		XFillRectangle(dpy, mpip->w, gc, x, y, width, height);
+	}
+}
+
 /* ---------------------------- interface functions ------------------------ */
 
 /* Allocates a new, empty menu item */
-MenuItem *menuitem_create(void)
+struct MenuItem *menuitem_create(void)
 {
 	MenuItem *mi;
 
@@ -135,9 +190,9 @@ MenuItem *menuitem_create(void)
 }
 
 /* Frees a menu item and all of its allocated resources. */
-void menuitem_free(MenuItem *mi)
+void menuitem_free(struct MenuItem *mi)
 {
-	short i;
+	int i;
 
 	if (!mi)
 	{
@@ -156,7 +211,7 @@ void menuitem_free(MenuItem *mi)
 	}
 	if (MI_PICTURE(mi))
 	{
-		PDestroyFvwmPicture(dpy,MI_PICTURE(mi));
+		PDestroyFvwmPicture(dpy, MI_PICTURE(mi));
 	}
 	for (i = 0; i < MAX_MENU_ITEM_MINI_ICONS; i++)
 	{
@@ -172,7 +227,7 @@ void menuitem_free(MenuItem *mi)
 
 /* Duplicate a menu item into newly allocated memory.  The new item is
  * completely independent of the old one. */
-MenuItem *menuitem_clone(MenuItem *mi)
+struct MenuItem *menuitem_clone(struct MenuItem *mi)
 {
 	MenuItem *new_mi;
 	int i;
@@ -214,12 +269,12 @@ MenuItem *menuitem_clone(MenuItem *mi)
 /* Calculate the size of the various parts of the item.  The sizes are returned
  * through mipst. */
 void menuitem_get_size(
-	MenuItem *mi, MenuItemPartSizesT *mipst, FlocaleFont *font,
-	Bool do_reverse_icon_order)
+	struct MenuItem *mi, struct MenuItemPartSizesT *mipst,
+	FlocaleFont *font, Bool do_reverse_icon_order)
 {
 	int i;
 	int j;
-	unsigned short w;
+	int w;
 
 	memset(mipst, 0, sizeof(MenuItemPartSizesT));
 	if (MI_IS_POPUP(mi))
@@ -305,10 +360,10 @@ void menuitem_get_size(
  *
  */
 void menuitem_paint(
-	MenuItem *mi, MenuPaintItemParameters *mpip)
+	struct MenuItem *mi, struct MenuPaintItemParameters *mpip)
 {
-	MenuStyle *ms = mpip->ms;
-	MenuDimensions *dim = mpip->dim;
+	struct MenuStyle *ms = mpip->ms;
+	struct MenuDimensions *dim = mpip->dim;
 
 	static FlocaleWinString *fws = NULL;
 	int y_offset;
@@ -324,7 +379,7 @@ void menuitem_paint(
 	int off_cs;
 	FvwmRenderAttributes fra;
 	/*Pixel fg, fgsh;*/
-	short relief_thickness = ST_RELIEF_THICKNESS(ms);
+	int relief_thickness = ST_RELIEF_THICKNESS(ms);
 	Bool is_item_selected;
 	Bool item_cleared = False;
 	Bool xft_clear = False;
@@ -445,11 +500,13 @@ void menuitem_paint(
 				2 * relief_thickness;
 			if (ST_DO_HILIGHT_BACK(ms))
 			{
-				XFillRectangle(
-					dpy, mpip->w, gcs.back_gc, lit_x_start,
+				draw_higlight_background(
+					mpip, lit_x_start,
 					y_offset + relief_thickness,
 					lit_x_end - lit_x_start,
-					y_height - relief_thickness);
+					y_height - relief_thickness,
+					(cs >= 0 ? &Colorset[cs] : NULL),
+					gcs.back_gc);
 				item_cleared = True;
 			}
 		}
@@ -491,9 +548,13 @@ void menuitem_paint(
 			MDIM_HILIGHT_WIDTH(*dim) > 0 &&
 			ST_DO_HILIGHT_TITLE_BACK(ms))
 		{
-			XFillRectangle(
-				dpy, mpip->w, gcs.back_gc, lit_x_start,
-				y_offset, lit_x_end - lit_x_start, y_height);
+			draw_higlight_background(
+				mpip, lit_x_start,
+				y_offset + relief_thickness,
+				lit_x_end - lit_x_start,
+				y_height - relief_thickness,
+				(cs >= 0 ? &Colorset[cs] : NULL),
+				gcs.back_gc);
 			item_cleared = True;
 		}
 	}
@@ -960,7 +1021,7 @@ void menuitem_paint(
 }
 
 /* returns the center y coordinate of the menu item */
-int menuitem_middle_y_offset(MenuItem *mi, MenuStyle *ms)
+int menuitem_middle_y_offset(struct MenuItem *mi, struct MenuStyle *ms)
 {
 	int r;
 
