@@ -60,7 +60,7 @@
 
 /* ---------------------------- local variables ---------------------------- */
 
-static unsigned int grab_count[GRAB_MAXVAL] = { 1, 1, 0, 0, 0, 0, 0 };
+static int grab_count[GRAB_MAXVAL] = { 1, 1, 0, 0, 0, 0, 0 };
 
 /* ---------------------------- exported variables (globals) --------------- */
 
@@ -516,10 +516,10 @@ int truncate_to_multiple (int x, int m)
 Bool IsRectangleOnThisPage(const rectangle *rec, int desk)
 {
 	return (desk == Scr.CurrentDesk &&
-		rec->x + rec->width > 0 &&
-		rec->x < Scr.MyDisplayWidth &&
-		rec->y + rec->height > 0 &&
-		rec->y < Scr.MyDisplayHeight) ?
+		rec->x + (signed int)rec->width > 0 &&
+		(rec->x < 0 || rec->x < Scr.MyDisplayWidth) &&
+		rec->y + (signed int)rec->height > 0 &&
+		(rec->y < 0 || rec->y < Scr.MyDisplayHeight)) ?
 		True : False;
 }
 
