@@ -73,7 +73,7 @@ typedef enum {
 typedef struct
 {
 	int cs;
-	unsigned short alpha_percent;
+	int alpha_percent;
 } FvwmAcs;
 
 typedef struct
@@ -161,7 +161,7 @@ typedef struct DecorFace
 		struct
 		{
 			int cs;
-			unsigned short alpha_percent;
+			int alpha_percent;
 		} acs;
 		Pixel back;
 		struct
@@ -170,7 +170,7 @@ typedef struct DecorFace
 			XColor *xcs;
 			int do_dither;
 			Pixel *d_pixels;
-			unsigned int d_npixels;
+			int d_npixels;
 			char gradient_type;
 		} grad;
 		struct vector_coords
@@ -333,9 +333,9 @@ typedef struct ScreenInfo
 	/* number of screens on display */
 	int NumberOfScreens;
 	/* my copy of DisplayWidth(dpy, screen) */
-	unsigned int MyDisplayWidth;
+	int MyDisplayWidth;
 	/* my copy of DisplayHeight(dpy, screen) */
-	unsigned int MyDisplayHeight;
+	int MyDisplayHeight;
 
 	/* the head of the fvwm window list */
 	FvwmWindow FvwmRoot;
