@@ -20,6 +20,7 @@
 
 #include <stdio.h>
 
+#include <X11/keysym.h>
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
 #include "libs/FGettext.h"
@@ -33,6 +34,7 @@
 #include "screen.h"
 #include "virtual.h"
 #include "module_interface.h"
+#include "module_list.h"
 #include "focus.h"
 #include "gnome.h"
 #include "ewmh.h"
@@ -78,17 +80,162 @@
  */
 static int edge_thickness = 2;
 static int last_edge_thickness = 2;
-static unsigned int prev_page_x = 0;
-static unsigned int prev_page_y = 0;
+static int prev_page_x = 0;
+static int prev_page_y = 0;
 static int prev_desk = 0;
 static int prev_desk_and_page_desk = 0;
-static unsigned int prev_desk_and_page_page_x = 0;
-static unsigned int prev_desk_and_page_page_y = 0;
+static int prev_desk_and_page_page_x = 0;
+static int prev_desk_and_page_page_y = 0;
 
 /* ---------------------------- exported variables (globals) --------------- */
 
 /* ---------------------------- local functions ---------------------------- */
 
+
+static void __drag_viewport(const exec_context_t *exc, int scroll_speed)
+{
+	XEvent e;
+	int x;
+	int y;
+	unsigned int button_mask = 0;
+	Bool is_finished = False;
+
+	if (!GrabEm(CRS_MOVE, GRAB_NORMAL))
+	{
+		XBell(dpy, 0);
+		return;
+	}
+
+	if (FQueryPointer(
+		    dpy, Scr.Root, &JunkRoot, &JunkChild, &x, &y,
+		    &JunkX, &JunkY, &button_mask) == False)
+	{
+		/* pointer is on a different screen */
+		/* Is this the best thing to do? */
+		UngrabEm(GRAB_NORMAL);
+		return;
+	}
+	MyXGrabKeyboard(dpy);
+	button_mask &= DEFAULT_ALL_BUTTONS_MASK;
+	memset(&e, 0, sizeof(e));
+	while (!is_finished)
+	{
+		int old_x;
+		int old_y;
+
+		old_x = x;
+		old_y = y;
+		FMaskEvent(
+			dpy, ButtonPressMask | ButtonReleaseMask |
+			KeyPressMask | PointerMotionMask |
+			ButtonMotionMask | ExposureMask |
+			EnterWindowMask | LeaveWindowMask, &e);
+		/* discard extra events before a logical release */
+		if (e.type == MotionNotify ||
+		    e.type == EnterNotify || e.type == LeaveNotify)
+		{
+			while (FPending(dpy) > 0 &&
+			       FCheckMaskEvent(
+				       dpy, ButtonMotionMask |
+				       PointerMotionMask | ButtonPressMask |
+				       ButtonRelease | KeyPressMask |
+				       EnterWindowMask | LeaveWindowMask, &e))
+			{
+				if (e.type == ButtonPress ||
+				    e.type == ButtonRelease ||
+				    e.type == KeyPress)
+				{
+					break;
+				}
+			}
+		}
+		if (e.type == EnterNotify || e.type == LeaveNotify)
+		{
+			XEvent e2;
+			int px;
+			int py;
+
+			/* Query the pointer to catch the latest information.
+			 * This *is* necessary. */
+			if (FQueryPointer(
+				    dpy, Scr.Root, &JunkRoot, &JunkChild, &px,
+				    &py, &JunkX, &JunkY, &JunkMask) == True)
+			{
+				fev_make_null_event(&e2, dpy);
+				e2.type = MotionNotify;
+				e2.xmotion.time = fev_get_evtime();
+				e2.xmotion.x_root = px;
+				e2.xmotion.y_root = py;
+				e2.xmotion.state = JunkMask;
+				e2.xmotion.same_screen = True;
+				e = e2;
+				fev_fake_event(&e);
+			}
+			else
+			{
+				/* pointer is on a different screen,
+				 * ignore event */
+			}
+		}
+		/* Handle a limited number of key press events to allow
+		 * mouseless operation */
+		if (e.type == KeyPress)
+		{
+			Keyboard_shortcuts(
+				&e, NULL, NULL, NULL, ButtonRelease);
+		}
+		switch (e.type)
+		{
+		case KeyPress:
+			/* simple code to bag out of move - CKH */
+			if (XLookupKeysym(&(e.xkey), 0) == XK_Escape)
+			{
+				is_finished = True;
+			}
+			break;
+		case ButtonPress:
+			if (e.xbutton.button <= NUMBER_OF_MOUSE_BUTTONS &&
+			    ((Button1Mask << (e.xbutton.button - 1)) &
+			     button_mask))
+			{
+				/* No new button was pressed, just a delayed
+				 * event */
+				break;
+			}
+			/* fall through */
+		case ButtonRelease:
+			x = e.xbutton.x_root;
+			y = e.xbutton.y_root;
+			is_finished = True;
+			break;
+		case MotionNotify:
+			if (e.xmotion.same_screen == False)
+			{
+				continue;
+			}
+			x = e.xmotion.x_root;
+			y = e.xmotion.y_root;
+			break;
+		case Expose:
+			dispatch_event(&e);
+			break;
+		default:
+			/* cannot happen */
+			break;
+		} /* switch */
+		if (x != old_x || y != old_y)
+		{
+			MoveViewport(
+				Scr.Vx + scroll_speed * (x - old_x),
+				Scr.Vy + scroll_speed * (y - old_y), False);
+			FlushAllMessageQueues();
+		}
+	} /* while*/
+	UngrabEm(GRAB_NORMAL);
+	MyXUngrabKeyboard(dpy);
+	WaitForButtonsUp(True);
+}
+
 /*
  *
  * Parse arguments for "Desk" and "MoveToDesk" (formerly "WindowsDesk"):
@@ -481,7 +628,7 @@ int HandlePaging(
 	int *delta_x, int *delta_y, Bool Grab, Bool fLoop,
 	Bool do_continue_previous)
 {
-	static unsigned int add_time = 0;
+	static int add_time = 0;
 	int x,y;
 	XEvent e;
 	static Time my_timestamp = 0;
@@ -502,7 +649,6 @@ int HandlePaging(
 	{
 		x = pev->xmotion.x_root;
 		y = pev->xmotion.y_root;
-		/* need to move the viewport */
 		if ((Scr.VxMax == 0 ||
 		     (x >= edge_thickness &&
 		      x < Scr.MyDisplayWidth  - edge_thickness)) &&
@@ -1143,18 +1289,18 @@ void MoveViewport(int newx, int newy, Bool grab)
 			/*
 			 * If the window is moving into the viewport...
 			 */
-			txl = t->frame_g.x;
-			tyt = t->frame_g.y;
-			txr = t->frame_g.x + t->frame_g.width - 1;
-			tyb = t->frame_g.y + t->frame_g.height - 1;
+			txl = t->g.frame.x;
+			tyt = t->g.frame.y;
+			txr = t->g.frame.x + t->g.frame.width - 1;
+			tyb = t->g.frame.y + t->g.frame.height - 1;
 			if (is_window_sticky_across_pages(t) &&
 			    !IS_VIEWPORT_MOVED(t))
 			{
 				/* the absolute position has changed */
-				t->normal_g.x -= deltax;
-				t->normal_g.y -= deltay;
-				t->max_g.x -= deltax;
-				t->max_g.y -= deltay;
+				t->g.normal.x -= deltax;
+				t->g.normal.y -= deltay;
+				t->g.max.x -= deltax;
+				t->g.max.y -= deltay;
 				/*  Block double move.  */
 				SET_VIEWPORT_MOVED(t, 1);
 			}
@@ -1179,10 +1325,10 @@ void MoveViewport(int newx, int newy, Bool grab)
 							t, False);
 					}
 					frame_setup_window(
-						t, t->frame_g.x + deltax,
-						t->frame_g.y + deltay,
-						t->frame_g.width,
-						t->frame_g.height, False);
+						t, t->g.frame.x + deltax,
+						t->g.frame.y + deltay,
+						t->g.frame.width,
+						t->g.frame.height, False);
 				}
 			}
 			/*  Bump to next win...  */
@@ -1195,10 +1341,10 @@ void MoveViewport(int newx, int newy, Bool grab)
 			 *If the window is not moving into the viewport...
 			 */
 			SET_VIEWPORT_MOVED(t, 1);
-			txl = t1->frame_g.x;
-			tyt = t1->frame_g.y;
-			txr = t1->frame_g.x + t1->frame_g.width - 1;
-			tyb = t1->frame_g.y + t1->frame_g.height - 1;
+			txl = t1->g.frame.x;
+			tyt = t1->g.frame.y;
+			txr = t1->g.frame.x + t1->g.frame.width - 1;
+			tyb = t1->g.frame.y + t1->g.frame.height - 1;
 			if (! (txr >= PageLeft && txl <= PageRight
 			       && tyb >= PageTop && tyt <= PageBottom)
 			    && !IS_VIEWPORT_MOVED(t1)
@@ -1218,10 +1364,10 @@ void MoveViewport(int newx, int newy, Bool grab)
 							t1, False);
 					}
 					frame_setup_window(
-						t1, t1->frame_g.x + deltax,
-						t1->frame_g.y + deltay,
-						t1->frame_g.width,
-						t1->frame_g.height, False);
+						t1, t1->g.frame.x + deltax,
+						t1->g.frame.y + deltay,
+						t1->g.frame.width,
+						t1->g.frame.height, False);
 				}
 			}
 			/*  Bump to next win...  */
@@ -1826,7 +1972,7 @@ void CMD_EdgeScroll(F_CMD_ARGS)
 			Scr.flags.do_edge_wrap_y = 1;
 		}
 	}
-	
+
 	Scr.EdgeScrollX = val1 * val1_unit / 100;
 	Scr.EdgeScrollY = val2 * val2_unit / 100;
 
@@ -2129,7 +2275,21 @@ void CMD_Scroll(F_CMD_ARGS)
 
 	if (GetTwoArguments(action, &val1, &val2, &val1_unit, &val2_unit) != 2)
 	{
-		/* to few parameters */
+		/* less then two integer parameters implies interactive
+		 * scroll check if we are scrolling in reverse direction */
+		char *option;
+		int scroll_speed = 1;
+
+		option = PeekToken(action, NULL);
+		if (option != NULL)
+		{
+			if (StrEquals(option, "Reverse"))
+			{
+				scroll_speed *= -1;
+			}
+		}
+		__drag_viewport(exc, scroll_speed);
+
 		return;
 	}
 	if ((val1 > -100000)&&(val1 < 100000))
