@@ -52,8 +52,8 @@ void FScreenSetPrimaryScreen(int scr);
 
 /* Screen info */
 Bool FScreenGetScrRect(
-	fscreen_scr_arg *arg, fscreen_scr_t screen, int *x, int *y, int *w,
-	int *h);
+	fscreen_scr_arg *arg, fscreen_scr_t screen, int *x, int *y,
+	int *w, int *h);
 Bool FScreenGetScrId(
 	fscreen_scr_arg *arg, fscreen_scr_t screen);
 void FScreenTranslateCoordinates(
@@ -61,7 +61,8 @@ void FScreenTranslateCoordinates(
 	fscreen_scr_arg *arg_dest, fscreen_scr_t screen_dest,
 	int *x, int *y);
 void FScreenGetResistanceRect(
-	int wx, int wy, int ww, int wh, int *x0, int *y0, int *x1, int *y1);
+	int wx, int wy, unsigned int ww, unsigned int wh, int *x0, int *y0,
+	int *x1, int *y1);
 Bool FScreenIsRectangleOnScreen(
 	fscreen_scr_arg *arg, fscreen_scr_t screen, rectangle *rec);
 void FScreenSpecToString(char *dest, int space, fscreen_scr_t screen);
