@@ -21,9 +21,9 @@
  * </description>
  */
 Bool PImageCreatePixmapFromArgbData(
-	Display *dpy, Window win, CARD32 *data, int start, unsigned int width,
-	unsigned int height, Pixmap pixmap, Pixmap mask, Pixmap alpha,
-	int *have_alpha, unsigned int *nalloc_pixels, Pixel **alloc_pixels,
+	Display *dpy, Window win, CARD32 *data, int start, int width,
+	int height, Pixmap pixmap, Pixmap mask, Pixmap alpha,
+	int *have_alpha, int *nalloc_pixels, Pixel **alloc_pixels,
 	int *no_limit, FvwmPictureAttributes fpa);
 /*
  * <pubfunc>PImageLoadPixmapFromFile
@@ -33,8 +33,8 @@ Bool PImageCreatePixmapFromArgbData(
  */
 Bool PImageLoadPixmapFromFile(
 	Display *dpy, Window win, char *file, Pixmap *pixmap, Pixmap *mask,
-	Pixmap *alpha, unsigned int *width, unsigned int *height, int *depth,
-	unsigned int *nalloc_pixels, Pixel **alloc_pixels, int *no_limit,
+	Pixmap *alpha, int *width, int *height, int *depth,
+	int *nalloc_pixels, Pixel **alloc_pixels, int *no_limit,
 	FvwmPictureAttributes fpa);
 
 /*
@@ -54,7 +54,7 @@ FvwmPicture *PImageLoadFvwmPictureFromFile(
  */
 Bool PImageLoadCursorPixmapFromFile(
 	Display *dpy, Window win, char *path, Pixmap *source, Pixmap *mask,
-	unsigned int *x, unsigned int *y);
+	int *x, int *y);
 
 /*
  * <pubfunc>PImageLoadPixmapFromFile
@@ -64,7 +64,7 @@ Bool PImageLoadCursorPixmapFromFile(
  */
 Bool PImageLoadPixmapFromXpmData(
 	Display *dpy, Window win, int color_limit, char **data,
-	Pixmap *pixmap, Pixmap *mask, unsigned int *width,
-	unsigned int *height, int *depth);
+	Pixmap *pixmap, Pixmap *mask, int *width,
+	int *height, int *depth);
 
 #endif /* PICTURE_IMAGE_LOADER_H  */
