@@ -229,7 +229,7 @@ int main ( int argc, char *argv[])
   {
     FILE *f;
 
-    if ((f = fopen (Fr_name,"r" )) != NULL)
+    if ((f = fopen (s,"r" )) != NULL)
     {
       *cmd = 0;
       fgets(cmd, 20, f);
@@ -607,7 +607,11 @@ void process_message( void )
       break;
 
     case M_CONFIG_INFO:
-      printf( "%s", (char *)&body[3] );
+      printf( "%s\n", (char *)&body[3] );
+      break;
+
+    case MX_REPLY:
+      list(body, "reply");
       break;
 
     default:
