@@ -181,6 +181,8 @@ void server (char *name)
 
   cix = 0;
 
+  /*Accept reply-messages */
+  SetMessageMask(Fd, MX_REPLY);
   /* tell fvwm we're running */
   SendFinishedStartupNotification(Fd);
 
@@ -513,6 +515,7 @@ void process_message(unsigned long type,unsigned long *body)
   case M_ERROR:
   case M_STRING:
   case M_CONFIG_INFO:
+  case MX_REPLY:
     msglen = strlen((char *)&body[3]);
     relay_packet(type, msglen + 1 + 3 * SOL, body);
     break;
@@ -552,8 +555,8 @@ void relay_packet(unsigned long type, unsigned long length,
 {
   Q *new;
 
-  if (!length || !body)
-    return;
+  if (!body)
+	  return;
 
   new = (Q *)safemalloc(sizeof(Q));
 
