@@ -405,11 +405,12 @@ void list_configure(unsigned long *body)
 		memcpy(&target.flags,
 		       &(cfgpacket->flags), sizeof(cfgpacket->flags));
 		target.title_h = cfgpacket->title_height;
+		target.title_dir = GET_TITLE_DIR(cfgpacket);
 		target.border_w = cfgpacket->border_width;
 		target.base_w = cfgpacket->hints_base_width;
 		target.base_h = cfgpacket->hints_base_height;
-		target.width_inc = cfgpacket->hints_width_inc;
-		target.height_inc = cfgpacket->hints_height_inc;
+		target.width_inc = cfgpacket->orig_hints_width_inc;
+		target.height_inc = cfgpacket->orig_hints_height_inc;
 		target.gravity = cfgpacket->hints_win_gravity;
 		target.ewmh_hint_layer = cfgpacket->ewmh_hint_layer;
 		target.ewmh_hint_desktop = cfgpacket->ewmh_hint_desktop;
@@ -790,8 +791,8 @@ void list_end(void)
 	{
 		int sx;
 		int sy;
-		unsigned int sw;
-		unsigned int sh;
+		int sw;
+		int sh;
 		Window JunkW;
 		int JunkC;
 		unsigned int JunkM;
@@ -1119,7 +1120,23 @@ void MakeList(void)
 
 	bw = 2*target.border_w;
 	width = target.frame_w - bw;
-	height = target.frame_h - target.title_h - bw;
+	height = target.frame_h - bw;
+	if (target.title_dir == DIR_W || target.title_dir == DIR_E)
+	{
+		width -= target.title_h;
+	}
+	else if (target.title_dir == DIR_N || target.title_dir == DIR_S)
+	{
+		height -= target.title_h;
+	}
+#define DEBUG_SIZE 0
+#if DEBUG_SIZE /*!!!*/
+	fprintf(
+		stderr, "frame %dx%d, bw %d, title %d(dir %d), client %dx%d\n",
+		(int)target.frame_w, (int)target.frame_h, (int)bw,
+		(int)target.title_h, (int)target.title_dir, (int)width,
+		(int)height);
+#endif
 
 	sprintf(desktop, "%ld",  target.desktop);
 	sprintf(layer,   "%ld",  target.layer);
@@ -1145,9 +1162,14 @@ void MakeList(void)
 
 	AddToList("StickyPage:",    (IS_STICKY_ACROSS_PAGES(targ) ? yes : no));
 	AddToList("StickyDesk:",    (IS_STICKY_ACROSS_DESKS(targ) ? yes : no));
+	AddToList("StickyPageIcon:",
+		(IS_ICON_STICKY_ACROSS_PAGES(targ) ? yes : no));
+	AddToList("StickyDeskIcon:",
+		(IS_ICON_STICKY_ACROSS_DESKS(targ) ? yes : no));
 	AddToList("NoTitle:",       (HAS_TITLE(targ)    ? no : yes));
 	AddToList("Iconified:",     (IS_ICONIFIED(targ) ? yes : no));
 	AddToList("Transient:",     (IS_TRANSIENT(targ) ? yes : no));
+	AddToList("WindowListSkip:", (DO_SKIP_WINDOW_LIST(targ) ? yes : no));
 
 	switch(target.gravity)
 	{
@@ -1208,8 +1230,18 @@ void MakeList(void)
 	{
 		y2 = 0;
 	}
+#if DEBUG_SIZE /*!!!*/
+	fprintf(
+		stderr, "client %dx%d, base %dx%d, inc %dx%d\n",
+		(int)width, (int)height, (int)target.base_w,
+		(int)target.base_h, (int)target.width_inc,
+		(int)target.height_inc);
+#endif
 	width = (width - target.base_w)/target.width_inc;
 	height = (height - target.base_h)/target.height_inc;
+#if DEBUG_SIZE /*!!!*/
+	fprintf(stderr, "--> units %dx%d\n", (int)width, (int)height);
+#endif
 
 	sprintf(loc,"%dx%d",width,height);
 	strcpy(geometry, loc);
