@@ -37,7 +37,8 @@ typedef struct
 {
   int count;
   Button *head, *tail;
-  int x, y, w, h, tw;
+  int x, y;
+  int w, h, tw;
 } ButtonArray;
 
 /* Function Prototypes */
