@@ -146,7 +146,7 @@ int AnimationDir=1;
 
 Window main_win;
 int Width, Height,win_x,win_y;
-unsigned int display_width, display_height;
+int display_width, display_height;
 
 #define MW_EVENTS   (ExposureMask | ButtonReleaseMask |\
 		     ButtonPressMask | LeaveWindowMask | EnterWindowMask)
@@ -525,7 +525,7 @@ void Loop(void)
 	  if (Event.xbutton.button == Button2) {
 	    static int LastX, LastY;
 	    static int scr_x, scr_y;
-	    static unsigned int scr_w, scr_h;
+	    static int scr_w, scr_h;
 
 	    if (LastMapped != -1) {
 	      CloseFolder(LastMapped);
@@ -1068,7 +1068,7 @@ void MapFolder(int folder, int *LastMapped, int base_x, int base_y, int row,
   {
     int folderx, foldery, folderw, folderh;
     int scr_x, scr_y;
-    unsigned int scr_w, scr_h;
+    int scr_w, scr_h;
     fscreen_scr_arg fscr;
 
     fscr.xypos.x = base_x;
